/*
 * iofile.d - I/O wait time by filename and process.
 *            Written using DTrace (Solaris 10 3/05).
 *
 * This prints the total I/O wait times for each filename by process.
 * This can help determine why an application is performing poorly by
 * identifying which file they are waiting on, and the total times.
 * Both disk and NFS I/O are measured.
 *
 * $Id: iofile.d 3 2007-08-01 10:50:08Z brendan $
 *
 * FIELDS:
 *		PID		Process ID
 *		CMD		Process name
 *		TIME		Total wait time for disk events, us
 *		FILE		File pathname
 *
 * BASED ON: /usr/demo/dtrace/iocpu.d
 *
 * SEE ALSO: iosnoop, iotop
 *
 * PORTIONS: Copyright (c) 2005, 2006 Brendan Gregg.
 *
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 * 24-Jul-2005	Brendan Gregg	Created this.
 * 20-Apr-2006	   "      "	Last update.
 * 13-Nov-2008	Tom Erickson	(updated for Chime)
 */

/*
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 */

/* save time at start */
io:::wait-start
{
	self->start = timestamp;
}

/* process event */
io:::wait-done
/self->start/
{
	/*
	 * wait-done is used as we are measing wait times. It also
	 * is triggered when the correct thread is on the CPU, obviating
	 * the need to link process details to the start event.
	 */
	this->elapsed = timestamp - self->start;
	@files[pid, execname, args[2]->fi_pathname] = sum(this->elapsed);
	self->start = 0;
}
